<template>
    <div class="system-add-user-container">
        <el-dialog :title="title" v-model="isShowUserDialog" width="769px">
            <el-form :model="userForm" size="default" ref="userRef" :rules="userFormRules" label-width="90px">
                <el-row :gutter="35">
                    <el-col :xs="24" :sm="12" :md="12" :lg="12" :xl="12" class="mb20">
                        <el-form-item label="用户名" prop="name">
                            <el-input v-model.trim="userForm.name" placeholder="用户名" clearable></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="12" :md="12" :lg="12" :xl="12" class="mb20">
                        <el-form-item label="真实姓名" prop="realName">
                            <el-input v-model.trim="userForm.realName" placeholder="真实姓名" clearable></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="12" :md="12" :lg="12" :xl="12" class="mb20" v-if="isAdd">
                      <el-form-item label="账户密码" prop="pwd">
                        <el-input v-model.trim="userForm.pwd" placeholder="账户密码" type="password" show-password>
                        </el-input>
                      </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="12" :md="12" :lg="12" :xl="12" class="mb20">
                        <el-form-item label="关联角色" prop="roleIds">
                            <el-select v-model="userForm.roleIds" placeholder="关联角色" clearable class="w100" multiple>
                                <el-option v-for="item in roleData" :key="item.id" :label="item.name" :value="item.id"> </el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="12" :md="12" :lg="12" :xl="12" class="mb20">
                        <el-form-item label="部门" prop="depId">
                            <el-cascader :options="departmentData" :props="{ emitPath: false, checkStrictly: true, value: 'id', label: 'depName' }" placeholder="部门" clearable class="w100" v-model="userForm.depId"> </el-cascader>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="12" :md="12" :lg="12" :xl="12" class="mb20">
                        <el-form-item label="手机号" prop="phone">
                            <el-input v-model.trim="userForm.phone" placeholder="手机号" clearable></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="12" :md="12" :lg="12" :xl="12" class="mb20">
                      <el-form-item label="证件类型" prop="idType">
                        <el-select v-model="userForm.idType" placeholder="证件类型" clearable class="w100">
                          <el-option :key="1" label="身份证" :value="1"> </el-option>
                        </el-select>
                      </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="12" :md="12" :lg="12" :xl="12" class="mb20">
                        <el-form-item label="证件号码" prop="idSerial">
                            <el-input v-model.trim="userForm.idSerial" placeholder="证件号码" clearable></el-input>
                        </el-form-item>
                    </el-col>
                </el-row>
            </el-form>
            <template #footer>
                <span class="dialog-footer">
                    <el-button @click="isShowUserDialog = !isShowUserDialog" size="default">取 消</el-button>
                    <el-button type="primary" v-throttle @click="onSubmit" size="default">确 定</el-button>
                </span>
            </template>
        </el-dialog>
    </div>
</template>

<script lang="ts">
import { reactive, toRefs, onMounted, defineComponent, ref } from 'vue';
import { ElMessageBox, ElMessage } from 'element-plus';
import { userApi } from '/@/api/systemManage/user';
import {checkChineseName, verifyFullName, verifyIdCard, verifyPhone} from "/@/utils/toolsValidate";

// 定义接口来定义对象的类型
interface DeptData {}
interface roleData {}
interface UserState {
    title: string;
    isShowUserDialog: boolean;
    userForm: {
        name: string;
        realName: string;
        roleIds: Array<any>
        depId: number | null;
        phone: string;
        pwd: string;
        idType: number | null;
        idSerial: string;
    };
    userFormRules:{

    },
    departmentData: Array<DeptData>;
    roleData: Array<roleData>;
    isAdd:boolean
}

export default defineComponent({
    name: 'userDialog',
    setup(props, context) {
        const userRef = ref()
        const state = reactive<UserState>({
            title: '',
            isShowUserDialog: false,
            userForm: {
                name: '', // 账户名称
                realName: '', // 用户昵称
                pwd: '', // 账户密码
                roleIds: [], // 关联角色
                depId: null, // 部门
                phone: '', // 手机号
                idType: 1,
                idSerial: '',
            },
            userFormRules:{
                name: [{ required: true, message: '请填写用户名', trigger: 'blur' }],
                realName: [{ required: true, message: '请填写真实姓名', trigger: 'blur' }],
                roleIds: [{ required: true, message: '请选择用户角色', trigger: 'change' }],
                depId: [{ required: true, message: '请选择部门', trigger: 'change' }],
                phone: [{ required: true, message: '请填写手机号', trigger: 'blur' }],
                idType: [{ required: true, message: '请选择证件类型', trigger: 'blur' }],
                idSerial: [{ required: true, message: '请填写证件号码', trigger: 'blur' }],
                pwd: [{ required: true, message: '请输入账户密码', trigger: 'blur' }],
            },
            departmentData: [], // 部门数据
            roleData: [], //角色数据
            isAdd: true
        });
        // 打开弹窗
        const openDialog = (type: string, value: any, departmentList: [], roleList: []) => {
            state.isShowUserDialog = true;
            state.departmentData = departmentList;
            state.roleData = roleList;
            if (type === '新增') {
                state.title = '新增用户';
                state.isAdd = true
                state.userForm = {
                    name: '',
                    realName: '',
                    roleIds: [],
                    depId: null,
                    phone: '',
                    idType: 1,
                    idSerial: '',
                    pwd: ''
                };
            } else {
                state.title = '修改用户';
                state.isAdd = false
                state.userForm = JSON.parse(JSON.stringify(value));
                state.userForm.roleIds = JSON.parse(JSON.stringify(value)).roles.map(i=>i.roleId)
            }
        };

        // 新增修改
        const onSubmit = async () => {
            userRef.value.validate(async (valid:Boolean) => {
                if(valid){
                    if(checkChineseName(state.userForm.realName) == false){
                      ElMessage({
                        type: 'warning',
                        message: '真实姓名格式有误',
                        duration: 2000
                      });
                      return
                    }
                    if(verifyPhone(state.userForm.phone) == false){
                      ElMessage({
                        type: 'warning',
                        message: '请输入正确的手机号',
                        duration: 2000
                      });
                      return
                    }
                    if(verifyIdCard(state.userForm.idSerial) == false){
                      ElMessage({
                        type: 'warning',
                        message: '请输入正确的证件号码',
                        duration: 2000
                      });
                      return
                    }
                    if (state.title === '新增用户') {
                        let res = await userApi().addUser(state.userForm);
                        if (res.data.code === 100) {
                            ElMessage({
                                type: 'success',
                                message: '用户新增成功',
                                duration: 2000
                            });
                            state.isShowUserDialog = false;
                            context.emit('getUserList');
                        } else {
                            ElMessage({
                                type: 'warning',
                                message: res.data.msg
                            });
                        }
                    } else {
                        const {name, realName, roleIds, depId, phone, idType, idSerial,id } = state.userForm
                        const data = {name, realName, roleIds, depId, phone, idType, idSerial,id}
                        let res = await userApi().modUser(data);
                        if (res.data.code === 100) {
                            ElMessage({
                                type: 'success',
                                message: '用户修改成功',
                                duration: 2000
                            });
                            state.isShowUserDialog = false;
                            context.emit('getUserList');
                        } else {
                            ElMessage({
                                type: 'warning',
                                message: res.data.msg
                            });
                        }
                    }
                }else{
                    ElMessage({
                        type:'warning',
                        message:'请完善基本信息'
                    })
                }
            })

        };

        // 页面加载时
        onMounted(() => {

        });
        return {
            userRef,
            openDialog,
            onSubmit,
            ...toRefs(state)
        };
    }
});
</script>
